==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/FeatureGateSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FeatureGateSpecBuilder extends io.fabric8.openshift.api.model.FeatureGateSpecFluentImpl<io.fabric8.openshift.api.model.FeatureGateSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.FeatureGateSpec,io.fabric8.openshift.api.model.FeatureGateSpecBuilder>{
  public FeatureGateSpecBuilder() {
    this(false);
  }
  public FeatureGateSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new FeatureGateSpec(), validationEnabled);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FeatureGateSpec(), validationEnabled);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent,io.fabric8.openshift.api.model.FeatureGateSpec instance) {
    this(fluent, instance, false);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent,io.fabric8.openshift.api.model.FeatureGateSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCustomNoUpgrade(instance.getCustomNoUpgrade()); 
    fluent.withFeatureSet(instance.getFeatureSet()); 
    this.validationEnabled = validationEnabled; 
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpec instance) {
    this(instance,false);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCustomNoUpgrade(instance.getCustomNoUpgrade()); 
    this.withFeatureSet(instance.getFeatureSet()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.FeatureGateSpec build() {
    FeatureGateSpec buildable = new FeatureGateSpec(fluent.getCustomNoUpgrade(),fluent.getFeatureSet());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSpecBuilder that = (FeatureGateSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/FeatureGateSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FeatureGateSpecBuilder extends io.fabric8.openshift.api.model.FeatureGateSpecFluentImpl<io.fabric8.openshift.api.model.FeatureGateSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.FeatureGateSpec,io.fabric8.openshift.api.model.FeatureGateSpecBuilder>{
  public FeatureGateSpecBuilder() {
    this(false);
  }
  public FeatureGateSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new FeatureGateSpec(), validationEnabled);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FeatureGateSpec(), validationEnabled);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent,io.fabric8.openshift.api.model.FeatureGateSpec instance) {
    this(fluent, instance, false);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent,io.fabric8.openshift.api.model.FeatureGateSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCustomNoUpgrade(instance.getCustomNoUpgrade()); 
    fluent.withFeatureSet(instance.getFeatureSet()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpec instance) {
    this(instance,false);
  }
  public FeatureGateSpecBuilder(io.fabric8.openshift.api.model.FeatureGateSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCustomNoUpgrade(instance.getCustomNoUpgrade()); 
    this.withFeatureSet(instance.getFeatureSet()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.FeatureGateSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.FeatureGateSpec build() {
    FeatureGateSpec buildable = new FeatureGateSpec(fluent.getCustomNoUpgrade(),fluent.getFeatureSet());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSpecBuilder that = (FeatureGateSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
